package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.RmsCapacityMapper;
import com.steerinfo.dil.mapper.RmsCarrierMapper;
import com.steerinfo.dil.model.RmsCapacity;
import com.steerinfo.dil.service.IRmsCapacityService;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:ZhouZhou
 * @CreateTime:2021/11/9 14:21
 * @Version:V1.0
 */
@Service(value = "rmsCapacityService")
public class RmsCapacityServiceImpl implements IRmsCapacityService {
    @Autowired
    RmsCapacityMapper rmsCapacityMapper;

    @Autowired
    RmsCarrierMapper rmsCarrierMapper;
    /*
    * 获取运力信息
    * */
    @Override
    public List<Map<String, Object>> getCapacityList(Map<String, Object> mapVal) {
        return rmsCapacityMapper.getCapacityList(mapVal);
    }

    /*
    * 增加运力信息
    * 如果车辆已存在  那就是更改承运商
    * */
    @Override
    public int insertCapacity(Map<String,Object> mapValue) {
        RmsCapacity rmsCapacity = new RmsCapacity();
        String capacityNumber = (String) mapValue.get("capacityNumber");
        BigDecimal carrierIds=DataChange.dataToBigDecimal(mapValue.get("carrierId"));
       // String carrierUserId = (String) mapValue.get("carrierUserId");
       // BigDecimal carrierId = rmsCarrierMapper.getCarrierIdByCarrierSSOId(carrierUserId);
        //如果车辆已存在  那就是更改承运商
        Integer capacityId = rmsCapacityMapper.selectBycapacityNumber(capacityNumber);
        if(capacityId != null){
            rmsCapacity.setCapacityId(new BigDecimal(capacityId));
            rmsCapacity.setCarrierId(carrierIds);
            return rmsCapacityMapper.updateByPrimaryKeySelective(rmsCapacity);
        }
        rmsCapacity.setCapacityId(rmsCapacityMapper.selectCapacityId());
        rmsCapacity.setCarrierId(carrierIds);
        rmsCapacity.setCapacityTypeId(DataChange.dataToBigDecimal(mapValue.get("capacityTypeId")));
        rmsCapacity.setCapacityNumber(capacityNumber);
        rmsCapacity.setCapacityCorlor((String) mapValue.get("capacityCorlor"));
        rmsCapacity.setCapacityOwneris((String)mapValue.get("capacityOwneris"));
        rmsCapacity.setCapacityVip((String)mapValue.get("capacityVip"));
        rmsCapacity.setCapacityBlacklist((String)mapValue.get("capacityBlacklist"));
        Object remark = mapValue.get("remark");
        if(remark != null && (!remark.toString().equals("null") || !remark.toString().equals("undefined"))){
            rmsCapacity.setInsertUpdateRemark(remark.toString());
        }
        rmsCapacity.setInsertUpdateRemark(((String)mapValue.get("remark")));
        rmsCapacity.setCapacitySsoId((String) mapValue.get("ssoId"));
        rmsCapacity.setCapacityStatus(new BigDecimal(0));
        rmsCapacity.setDeleted(new BigDecimal(0));
        rmsCapacity.setInsertTime(new Date());
        rmsCapacity.setInsertUsername("admin");
        return rmsCapacityMapper.insertSelective(rmsCapacity);
    }

    /*
    * 修改运力信息
    * */
    @Override
    public int updateCapacity(RmsCapacity rmsCapacity) {
        rmsCapacity.setUpdateTime(new Date());
        rmsCapacity.setUpdateUsername("admin");
        return rmsCapacityMapper.updateByPrimaryKeySelective(rmsCapacity);
    }

    /*
    * 删除运力信息
    * */
    @Override
    public int deleteCapacity(BigDecimal id) {
        return  rmsCapacityMapper.deleteByPrimaryKey(id);
    }

    /**
     * 根据id获取运力信息
     * @param id
     * @return
     */
    @Override
    public List<Map<String, Object>> getCapacityById(BigDecimal id) {
        return rmsCapacityMapper.getCapacityById(id);
    }

    /*
    * 获取下拉框
    * */
    @Override
    public  List<Map<String,Object>> getCapacityTypeId() {
        return rmsCapacityMapper.getCapacityTypeId();
    }

    /*
    * 查询carrierSSOId是否在承运商表中存在
    * */
    @Override
    public Map<String,Object> getCarrierNameBySSOId(String carrierSSOId) {
        Map<String,Object> map= rmsCapacityMapper.getCarrierNameBySSOId(carrierSSOId);
        return map;
    }

    //获取承运商id
    @Override
    public List<Map<String, Object>> getCarrierId() {
        return rmsCapacityMapper.getCarrierId();
    }
}
